<?php
// $Id: unitrack.admin.inc,v 1.6 2011/02/21 17:28:38 valthebald Exp $

/**
 * @file
 * Provides the administration page for Unitrack.
 */
  
/**
 * Administration page for UniTrack.
 */
function unitrack_settings_page() {
  $args = func_get_args();
  if (!count($args)) {
    $out = drupal_get_form('unitrack_accounts_overview_form');
  }
  else {
    $account_id = intval($args[1]);
    $out = drupal_get_form('unitrack_account_config', $account_id);
  }
  return $out;
}

function unitrack_accounts_overview_form() {
  $providers = unitrack_get_providers(FALSE, TRUE);
  $accounts = unitrack_get_accounts_list();
  
  $form['general_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('General settings'),
  );
  $form['general_settings']['history_ttl'] = array(
    '#type' => 'textfield',
    '#title' => t('Visitors history storage (days)'),
    '#description' => t('How long to store visitors activity history (in days). 0 means do not store, -1 means store forever (use with care)'),
    '#default_value' => variable_get('unitrack_storage_period', 60),
  );
  
  $header = array(
    'title' => array('data' => t('Type'), 'field' => 'n.title'),
    'status' => array('data' => t('Status'), 'field' => 'n.status'),
    'operations' => array('data' => t('Operations'), 'field' => 'n.changed')
  );
  
  $rows = array();
  foreach ($providers as $provider) {
    require_once $provider->file_name;
    $worker = new $provider->class_name;
    $row = array(
      'title' => $provider->title,
      'status' => $provider->enabled ? t('Enabled') : t('Disabled'),
    );
    if (method_exists($worker, 'adminForm')) {
      $row['operations'] = l(t('Configure'), 'admin/config/system/unitrack/account_conf/' . $provider->id);
    }
    $rows[] = $row;
  }
  
  $form['providers'] = array(
    '#theme' => 'table',
    '#header' => $header,
    '#rows' => $rows,
    '#empty' => t('No content available.'),
  );
  
  $form['submit'] = array('#type' => 'submit', '#value' => t('Apply changes'));
  
  return $form;
}

function unitrack_accounts_overview_form_submit($form, &$form_state) {
  $accounts_list = unitrack_get_accounts_list();
  variable_set('unitrack_storage_period', $form_state['values']['history_ttl']);
  foreach ($accounts_list as $account_id => $account) {
    if($form_state['values']["enabled_{$account_id}"]) {
      db_query('UPDATE {unitrack_types} SET enabled = 1 WHERE id = %d', $account_id);
    } else {
      db_query('UPDATE {unitrack_types} SET enabled = 0 WHERE id = %d', $account_id);
    }
  }
}

function unitrack_get_account_name($account_id) {
  $accounts_list = unitrack_get_accounts_list();
  return $accounts_list[$account_id]['name'];
}

function unitrack_account_config() {
  $args = func_get_args();
  $account_id = $args[2];
  $providers = unitrack_get_providers(FALSE);
  $form = array(
    'backlink' => array('#markup' => l(t('Back to overview'), 'admin/config/system/unitrack')),
    'enabled' => array('#type' => 'checkbox', '#title' => t('Enabled'), '#return_value' => '1', '#default_value' => $providers[$account_id]->enabled),
  );
  if (!empty($providers[$account_id])) {
    require_once $providers[$account_id]->file_name;
    $worker = new $class_name;
    $form += $worker->adminForm();
  }
  else {
    $form['message'] = array('#markup' => t('Wrong account type'));
  }
  $form['op'] = array('#type' => 'submit', '#value' => t('Save'));
  return $form;
}

function unitrack_account_config_submit($form, &$form_state) {
  $account_id = $form_state['build_info']['args'][0];
  $providers = unitrack_get_providers(FALSE);
  if (!empty($providers[$account_id])) {
    require_once $providers[$account_id]->file_name;
    $worker = new $providers[$account_id]->class_name;
    if (method_exists($worker, 'adminFormSubmit')) {
      $worker->adminFormSubmit($form, $form_state);
    }
  }
  db_query('UPDATE {unitrack_providers} SET enabled = :enabled WHERE id = :id',
    array(':enabled' => $form_state['values']['enabled'], ':id' => $account_id));
  drupal_set_message(t('Changes saved'));
}